.. :changelog:

History
-------

0.3.0 (2023-04-24)
++++++++++++++++++

* Add support for Wagtail>=5
* Drop support for Wagtail<3.0
* Added workaround for image_node.filter_spec -> image_node.filter_specs change in Wagtail 5
* Some small spelling fixes and extended docstrings
* pre-commit autoupdate
* make tox check against python (3.9, 3.10, 3.11) and wagtail (3, 4, 5)
* fixed codecov.io workflow
* added supported python and wagtail versions to readme via badges

0.2.0 (2022-11-03)
++++++++++++++++++

* Replace poetry with flit
* Make tox run tests with flit for last 3 Python versions
* Updated dependencies

0.1.5 (2020-05-21)
++++++++++++++++++

* Bumped down python requirement to 3.6 (since f-strings are used) - requeste by CVYY39
* Updated dependencies

0.1.4 (2020-04-22)
++++++++++++++++++

* Updated dependencies

0.1.3 (2020-04-13)
++++++++++++++++++

* Add original url to rendition generated by "as" syntax

0.1.2 (2020-04-05)
++++++++++++++++++

* Added support for wagtails "as" syntax

0.1.0 (2019-XX-YY)
++++++++++++++++++

* First release
